<template>
  <el-dialog v-dialogDrag
             :title="paramVOS.title"
             :visible.sync="visible"
             :width="width"
             :fullscreen="paramVOS.content || paramVOS.context"
             :append-to-body="true"
             class="avue-dialog avue-dialog--top"
             :destroy-on-close="true"
             @close="dialogClose">
    <basic-form ref="formRef" v-if="paramVOS.form"
                :span="span"
                :formItems="formItems"
                :formData="form">
    </basic-form>
    <ui-view ref="uiViewRef" v-else-if="paramVOS.content || paramVOS.context"
             :btmType="paramVOS.type"
             :context="paramVOS.context"
             :inDialog="true"
             :key="'AddEditDialog-'+type"
             :sourceData="sourceData"
             :dataStore="dataStore"
             :paramVOS="paramVOS"
    ></ui-view>
    <div slot="footer" class="dialog-footer avue-dialog__footer">
      <el-button type="primary" plain size="small" @click="saveHandler">保 存</el-button>
      <el-button size="small" @click="dialogClose">取 消</el-button>
      <el-button size="small" @click="resetValue">重 置</el-button>
    </div>
  </el-dialog>
</template>

<script>
import uiView from "@/views/base/UIContentViewerInDialog"
import {getFormDefineById,dataForm} from "@/api/base/ui";
import {addSave,editSave} from "@/api/base/actions"

export default {
  name: "AddEditDialog",
  components:{uiView},
  props: {
    sourceData: {
      //所属区域的上一区域选中数据
      type: Object,
      default: {}
    },
    dataStore: {
      //弹窗时按钮所属区域选中数据
      type: Array,
      default: []
    },
    paramVOS: {
      type: Object,
      default: {}
    },
    width: {
      type: String,
      default:'60%'
    }
  },
  data(){
    return {
      type:"add",
      visible:false,
      span:12,
      formItems:[],
      form:{}
    }
  },
  computed:{
    title(){
      return this.paramVOS.title || (this.type=='add'?'添加':'修改')
    }
  },
  created() {
  },
  watch: {
    sourceData: {
      handler(val) {
        if (this.paramVOS.form) {
          this.onLoad();
        }
      },
      deep: true,
      immediate: true
    },
  },
  methods: {
    dialogClose() {
      this.visible = false;
    },
    onLoad: function () {
      if (Object.keys(this.sourceData).length > 0) {
        this.loading = true;
        getFormDefineById(this.paramVOS.type,this.paramVOS.form).then(result => {
          this.formItems=result.data.obj.items;
          this.span=result.data.obj.columnOneRow?(24/result.data.obj.columnOneRow) : 12;

          if (this.paramVOS.initvalue) {
            this.form=this.paramVOS.initvalue;
          }
          if(this.type=="edit"){
            //加载表单数据
            dataForm(this.params,this.paramVOS.getdataurl,this.paramVOS.getdatamethod).then(res => {
              this.form = res.data.obj;
              this.loading = false;
            }).catch(error => {
              this.$message.error(error);
              this.loading = false;
            });
          }
        }).catch(error => {
          this.$message.error(error);
          this.loading = false;
        });

      }
    },
    saveHandler() {
      this.$refs.formRef.validate((valid, done) => {
        if (valid) {
          if(this.type=="add"){
            addSave(this.form,this.paramVOS.url,this.paramVOS.method).then(() => {
              this.$message({
                type: "success",
                message: "保存成功!"
              });
              if(this.saveCallback){
                this.saveCallback();
              }
              this.dialogClose();
            }).error((e) => {
              this.$message.error(e||"保存失败")
            });
          }else{
            editSave(this.form,this.paramVOS.url,this.paramVOS.method).then(() => {
              this.$message({
                type: "success",
                message: "修改成功!"
              });
              if(this.saveCallback){
                this.saveCallback();
              }
              this.dialogClose();
            }).error((e) => {
              this.$message.error(e||"修改失败")
            });
          }
        } else {

        }
      });
    },
    resetValue() {
      this.$refs.formRef.resetFields();
    }
  }
}
</script>

<style scoped>
.avue-dialog__footer{
  margin-bottom: 20px;
}
</style>
